<%inherit file="admin_basewithmenu.html" /> <%block name="head"> ${parent.head()}
<%block name="menu2">
×

### Create IP

IP:

Total limit:

Hourly limit:

Processing

×

### Change total request limit

IP:

Total limit:

Processing

×

### Change hourly request limit

IP:

Hourly limit:

Processing

×

### Delete a IP

IP to delete:

Processing

×

### Reset hourly request counter

Counter to reset:

Processing